==> huaweicloudsdkfunctiongraph-3.1.93-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/version_strategy.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VersionStrategy:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'rules': 'list[VersionStrategyRules]',
        'combine_type': 'str'
    }

    attribute_map = {
        'rules': 'rules',
        'combine_type': 'combine_type'
    }

    def __init__(self, rules=None, combine_type=None):
        """VersionStrategy

        The model defined in huaweicloud sdk

        :param rules: 规则列表
        :type rules: list[:class:`huaweicloudsdkfunctiongraph.v2.VersionStrategyRules`]
        :param combine_type: 所有规则聚合方式。and：所有规则都满足，or：满足其中一个
        :type combine_type: str
        """
        
        

        self._rules = None
        self._combine_type = None
        self.discriminator = None

        if rules is not None:
            self.rules = rules
        if combine_type is not None:
            self.combine_type = combine_type

    @property
    def rules(self):
        """Gets the rules of this VersionStrategy.

        规则列表

        :return: The rules of this VersionStrategy.
        :rtype: list[:class:`huaweicloudsdkfunctiongraph.v2.VersionStrategyRules`]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this VersionStrategy.

        规则列表

        :param rules: The rules of this VersionStrategy.
        :type rules: list[:class:`huaweicloudsdkfunctiongraph.v2.VersionStrategyRules`]
        """
        self._rules = rules

    @property
    def combine_type(self):
        """Gets the combine_type of this VersionStrategy.

        所有规则聚合方式。and：所有规则都满足，or：满足其中一个

        :return: The combine_type of this VersionStrategy.
        :rtype: str
        """
        return self._combine_type

    @combine_type.setter
    def combine_type(self, combine_type):
        """Sets the combine_type of this VersionStrategy.

        所有规则聚合方式。and：所有规则都满足，or：满足其中一个

        :param combine_type: The combine_type of this VersionStrategy.
        :type combine_type: str
        """
        self._combine_type = combine_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionStrategy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfunctiongraph-3.1.158-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/version_strategy.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VersionStrategy:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'rules': 'list[VersionStrategyRules]',
        'combine_type': 'str'
    }

    attribute_map = {
        'rules': 'rules',
        'combine_type': 'combine_type'
    }

    def __init__(self, rules=None, combine_type=None):
        r"""VersionStrategy

        The model defined in huaweicloud sdk

        :param rules: 规则列表
        :type rules: list[:class:`huaweicloudsdkfunctiongraph.v2.VersionStrategyRules`]
        :param combine_type: 所有规则聚合方式。and：所有规则都满足，or：满足其中一个
        :type combine_type: str
        """
        
        

        self._rules = None
        self._combine_type = None
        self.discriminator = None

        if rules is not None:
            self.rules = rules
        if combine_type is not None:
            self.combine_type = combine_type

    @property
    def rules(self):
        r"""Gets the rules of this VersionStrategy.

        规则列表

        :return: The rules of this VersionStrategy.
        :rtype: list[:class:`huaweicloudsdkfunctiongraph.v2.VersionStrategyRules`]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        r"""Sets the rules of this VersionStrategy.

        规则列表

        :param rules: The rules of this VersionStrategy.
        :type rules: list[:class:`huaweicloudsdkfunctiongraph.v2.VersionStrategyRules`]
        """
        self._rules = rules

    @property
    def combine_type(self):
        r"""Gets the combine_type of this VersionStrategy.

        所有规则聚合方式。and：所有规则都满足，or：满足其中一个

        :return: The combine_type of this VersionStrategy.
        :rtype: str
        """
        return self._combine_type

    @combine_type.setter
    def combine_type(self, combine_type):
        r"""Sets the combine_type of this VersionStrategy.

        所有规则聚合方式。and：所有规则都满足，or：满足其中一个

        :param combine_type: The combine_type of this VersionStrategy.
        :type combine_type: str
        """
        self._combine_type = combine_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionStrategy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
